/*
 * dtrace.h - dtrace header.
 *
 * $Id: dtrace.h 28 2006-02-09 12:34:42Z brendan $
 *
 * CDDL HEADER START
 *
 * The contents of this file are subject to the terms of the
 * Common Development and Distribution License, Version 1.0 only
 * (the "License").  You may not use this file except in compliance
 * with the License.
 *
 * You can obtain a copy of the license at usr/src/OPENSOLARIS.LICENSE
 * or http://www.opensolaris.org/os/licensing.
 * See the License for the specific language governing permissions
 * and limitations under the License.
 *
 * When distributing Covered Code, include this CDDL HEADER in each
 * file and include the License file at usr/src/OPENSOLARIS.LICENSE.
 * If applicable, add the following below this CDDL HEADER, with the
 * fields enclosed by brackets "[]" replaced with your own identifying
 * information: Portions Copyright [yyyy] [name of copyright owner]
 *
 * CDDL HEADER END
 *
 * COPYRIGHT: Copyright (c) 2006 Brendan Gregg.
 *
 * 29-Jan-2006  Brendan Gregg   Created this
 */

#ifndef DTRACE_H
#define	DTRACE_H

#include <gtk/gtk.h>
#include <stdio.h>

/* routine */
#define	BUF_SIZE	8192
#define	LINE_LEN	256
#define	DEBUG		0

/*
 * DTrace state
 *
 * tracing on/off. this is a global variable so that the main program
 * can read the internal state of DTrace at any time. it is maintained
 * by the code in dtrace.c.
 */
enum dt_state {
	DT_STATE_STARTED,
	DT_STATE_STOPPED,
	DT_STATE_ERR
};
extern enum dt_state	dt_state;

/*
 * DTrace script type
 *
 * this sets the type of dtrace script to run. single slice or whole disk.
 */
enum dt_script {
	DT_SCRIPT_SINGLE,
	DT_SCRIPT_WHOLE,
	DT_SCRIPT_READWRITE
};
extern enum dt_script	dt_script;

/* other public variables */
extern int	dt_heartbeat;			/* heartbeat delay ms */

/* start dtrace. */
extern int dtrace_start(enum dt_script, dev_t);

/* check dtrace is running. */
extern int dtrace_isrunning(void);

/* close dtrace. */
extern int dtrace_close(void);

/* read from dtrace. */
extern int dtrace_read(char *);

/* terminate and close dtrace. */
extern int dtrace_terminate(void);

/* check the pulse of dtrace, and stop if needed. */
extern int dtrace_checkpulse(int);

#endif /* DTRACE_H */
